@@ -1,32 +1,25 @@
-# 
-# This file is part of Padre-Plugin-Plack
-# 
-# This software is copyright (c) 2010 by Patrick Donelan.
-# 
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-# 
 package Padre::Plugin::Plack;
 BEGIN {
-  $Padre::Plugin::Plack::VERSION = '0.101150';
+  $Padre::Plugin::Plack::VERSION = '1.200';
 }
+
 # ABSTRACT: PSGI/Plack plugin for Padre
-use base 'Padre::Plugin';
 
 use warnings;
 use strict;
+use base 'Padre::Plugin';
 use utf8;
 
 use Padre::Util ('_T');
 use Padre::Logger;
 
-# Declare the Padre interfaces this plugin uses
+
 sub padre_interfaces {
-    'Padre::Plugin' => 0.43,
-    'Padre::Document' => 0.57;
+    'Padre::Plugin'     => 0.43,
+      'Padre::Document' => 0.57;
 }
 
-# Declare ourselves as the handler for .psgi files
+
 sub registered_documents {
     'application/x-psgi' => 'Padre::Document::PSGI';
 }
@@ -34,7 +27,7 @@ sub registered_documents {
 # Static cache for the dot-psgi examples (read off disk)
 my %PSGI_EXAMPLES;
 
-# Create the plugin menu
+
 sub menu_plugins {
     my $self = shift;
     my $main = shift;
@@ -74,16 +67,13 @@ sub menu_plugins {
         },
     );
 
-    Wx::Event::EVT_MENU(
-        $main,
-        $menu->Append( -1, _T('About') ),
-        sub { $self->on_about_load },
-    );
+    Wx::Event::EVT_MENU( $main, $menu->Append( -1, _T('About') ), sub { $self->on_about_load }, );
 
     # Return it and the label for our plug-in
     return ( $self->plugin_name => $menu );
 }
 
+
 sub on_app_load {
     my $self = shift;
     my $file = shift;
@@ -114,88 +104,97 @@ sub on_app_load {
     $doc->set_tab_icon;
 }
 
+
 sub is_psgi_doc {
     my $self = shift;
-    my $doc = shift;
-    
+    my $doc  = shift;
+
     return $doc->isa('Padre::Document::PSGI') && $doc->can('mimetype') && $doc->mimetype eq 'application/x-psgi';
 }
 
+
 sub editor_enable {
-    my $self     = shift;
-    my $editor   = shift;
-    my $doc      = shift;
-    
+    my $self   = shift;
+    my $editor = shift;
+    my $doc    = shift;
+
     # Only respond to event on psgi docs
     return unless $self->is_psgi_doc($doc);
-    
+
     TRACE('->editor_enable') if DEBUG;
-    
+
     $self->on_doc_load($doc);
 
     # Deliberately don't trigger Padre::Document::PSGI::set_tab_icon here because the tab doesn't exist yet
     # (it gets triggered by our tomfoolery in Padre::Document::PSGI::restore_cursor_position)
 }
 
+
 sub editor_changed {
     my $self = shift;
-    
-    my $main = $self->main or return;
+
+    my $main   = $self->main            or return;
     my $editor = $main->current->editor or return;
-    my $doc    = $editor->{Document}  or return;
-    
+    my $doc    = $editor->{Document}    or return;
+
     # Only respond to event on psgi docs
     return unless $self->is_psgi_doc($doc);
-    
+
     TRACE('->editor_changed') if DEBUG;
-    
+
     ## TODO: add check that doc is now selected (for safety)..
     $self->on_panel_load($doc);
 }
 
+
 sub on_panel_load {
     my $self = shift;
-    my $doc = shift;
-    
-    if (!$doc->panel) {
+    my $doc  = shift;
+
+    if ( !$doc->panel ) {
         TRACE('->on_panel_load creating panel') if DEBUG;
         require Padre::Plugin::Plack::Panel;
         $doc->panel( Padre::Plugin::Plack::Panel->new($doc) );
     }
-    
+
     # Show the panel, and pass an onclose callback
-    Padre::Current->main->bottom->show( $doc->panel, sub {
-        # Closing the panel causes bad things to happen
-        $self->main->error(_T(q{'Sorry Dave, I can't do that - you need to close the corresponding file tab to close this panel}));
-        
-        # We can't actually cancel the close, so re-create it
-        $self->plackdown($doc);
-        $doc->panel(undef); 
-        $self->on_panel_load($doc); 
-    });
+    Padre::Current->main->bottom->show(
+        $doc->panel,
+        sub {
+
+            # Closing the panel causes bad things to happen
+            $self->main->error(
+                _T(q{'Sorry Dave, I can't do that - you need to close the corresponding file tab to close this panel})
+            );
+
+            # We can't actually cancel the close, so re-create it
+            $self->plackdown($doc);
+            $doc->panel(undef);
+            $self->on_panel_load($doc);
+        }
+    );
     Padre::Current->main->refresh;
 }
 
+
 sub on_panel_close {
     my $self = shift;
-    my $doc = shift;
-    
+    my $doc  = shift;
+
     return unless $doc && $doc->panel;
-    
-    if (my $panel = $doc->panel) {
+
+    if ( my $panel = $doc->panel ) {
         $self->plackdown($doc);
-        $self->main->bottom->hide( $panel );
+        $self->main->bottom->hide($panel);
         $doc->panel(undef);
     }
 }
 
-# Note that the new tab may or may not exist at this point
-# When triggered by user opening a new file (e.g. from L<on_app_load>), tab does not exist yet
-# Whereas, when triggered by user creating new app from template, tab exists
+
 sub on_doc_load {
     my $self = shift;
     my $doc  = shift;
-    
+
     TRACE('->on_doc_load') if DEBUG;
 
     if ( !$doc->isa('Padre::Document::PSGI') ) {
@@ -209,38 +208,38 @@ sub on_doc_load {
 
     # Trigger the Document's general setup event
     $doc->on_load;
-    
+
     # Show the panel
     $self->on_panel_load($doc);
 }
 
+
 sub on_doc_close {
     my $self = shift;
     my $doc  = shift;
-    
+
     TRACE('->on_doc_close') if DEBUG;
-    
+
     if ( !$doc->isa('Padre::Document::PSGI') ) {
         $self->error( sprintf( _T('Expected a PSGI document, but instead got: %s'), ref $doc ) );
         return;
     }
-    
+
     $self->on_panel_close($doc);
 }
 
+
 sub on_about_load {
     require Plack;
     require Class::Unload;
     my $about = Wx::AboutDialogInfo->new;
     $about->SetName("Padre::Plugin::Plack");
-    $about->SetDescription( 
-            _T('PSGI/Plack support for Padre') . "\n"
+    $about->SetDescription( _T('PSGI/Plack support for Padre') . "\n"
           . _T('by') . "\n"
           . 'Patrick Donelan (pat@patspam.com)' . "\n\n"
           . _T('This system is running Plack version')
           . " $Plack::VERSION\n"
-          . 'http://plackperl.org'
-    );
+          . 'http://plackperl.org' );
     $about->SetVersion($Padre::Plugin::Plack::VERSION);
     Class::Unload->unload('Plack');
 
@@ -248,22 +247,26 @@ sub on_about_load {
     return;
 }
 
+
 sub load_dot_psgi_examples {
     my $self = shift;
 
     require File::Find::Rule;
     %PSGI_EXAMPLES =
       map { File::Basename::basename($_) => $_ }
-      File::Find::Rule->file()->name('*.psgi')
-      ->in( $self->plugin_directory_share . '/dot-psgi' );
+      File::Find::Rule->file()->name('*.psgi')->in( $self->plugin_directory_share . '/dot-psgi' );
 }
 
+
+
+
 sub plugin_enable {
     my $self = shift;
 
     $self->load_dot_psgi_examples;
 }
 
+
 sub plugin_disable {
     my $self = shift;
 
@@ -275,17 +278,18 @@ sub plugin_disable {
     Class::Unload->unload('Padre::Plugin::Plack::Panel');
 }
 
+
 sub plackup {
     my $self = shift;
-    my $doc = shift;
-    
+    my $doc  = shift;
+
     return unless $doc;
     TRACE('->plackup') if DEBUG;
-    
+
     my $main     = $self->main;
     my $filename = $doc->filename;
-    
-    if (!$filename) {
+
+    if ( !$filename ) {
         $main->on_save;
         $filename = $doc->filename;
         return unless $filename;
@@ -293,83 +297,88 @@ sub plackup {
 
     my $pwd = Cwd::cwd();
     chdir $doc->dirname;
-    
+
     # Server ("Let plackup guess" means leave as unspecified)
     my $server = $doc->panel->{server}->GetValue;
     $server = $server eq _T('Let plackup guess') ? '' : "-s $server";
-    
+
     # Port (required for browser url)
     my $port = $doc->panel->{port}->GetValue || 5000;
     $port = "-p $port";
-    
+
     my $restart = $doc->panel->{restart}->GetValue ? '-r' : '';
     my $plackup_options = $doc->panel->{plackup_options}->GetValue;
-    
+
     require File::Which;
     my $plackup = File::Which::which('plackup');
-    if (!$plackup) {
-        $main->error(_T('plackup command not found, please check your Plack installation and $PATH'));
+    if ( !$plackup ) {
+        $main->error( _T('plackup command not found, please check your Plack installation and $PATH') );
         return;
     }
-    
+
     my $cmd = qq{$plackup $port $restart $server $plackup_options "$filename"};
     TRACE("->plackup $cmd") if DEBUG;
-    $self->run_command($doc, $cmd);
+    $self->run_command( $doc, $cmd );
 
     # restore previous dir
     chdir $pwd;
 }
 
+
 sub plackdown {
     my $self = shift;
-    my $doc = shift;
-    
+    my $doc  = shift;
+
     return unless $doc;
-    
+
     TRACE('->plackdown') if DEBUG;
-    
+
     my $process = $doc->process;
     return unless $process;
-        
+
     # sanity check
-    if (!$process->IsAlive) {
+    if ( !$process->IsAlive ) {
         TRACE('->plackdown process was dead but not undef, strange') if DEBUG;
         $doc->process(undef);
     }
-    
+
     my $processid = $process->GetProcessId();
-    my $panel = $doc->panel;
-    
+    my $panel     = $doc->panel;
+
     require Proc::Killfam;
     my @signals = qw(INT TERM QUIT KILL STOP);
     for my $sig (@signals) {
-        TRACE( "Sending $sig to PID: $processid" ) if DEBUG;
-        my $signalled = Proc::Killfam::killfam($sig, $processid);
-        
-        if ($panel->{restart}->GetValue) {
+        TRACE("Sending $sig to PID: $processid") if DEBUG;
+        my $signalled = Proc::Killfam::killfam( $sig, $processid );
+
+        if ( $panel->{restart}->GetValue ) {
+
             # with auto-restart, we expect 3 processes
             return if $signalled > 1;
-        } else {
+        }
+        else {
+
             # otherwise, just one
             return if $signalled > 0;
         }
     }
-    
-    $panel->output->AppendText("\n" . "Process PID $processid did not respond, you may need to kill it manually\n" );
+
+    $panel->output->AppendText( "\n" . "Process PID $processid did not respond, you may need to kill it manually\n" );
 }
 
+
 sub run_command {
     my ( $self, $doc, $command ) = (@_);
-    
+
     my $panel = $doc->panel;
 
     # clear the panel
     $panel->output->Remove( 0, $panel->output->GetLastPosition );
 
     # If this is the first time a command has been run, set up the ProcessStream bindings.
-    unless ($panel->{bound}) {
+    unless ( $panel->{bound} ) {
         TRACE(' setting up ProcessStream bindings') if DEBUG;
-        
+
         require Wx::Perl::ProcessStream;
         if ( $Wx::Perl::ProcessStream::VERSION < .20 ) {
             $self->main->error(
@@ -411,15 +420,15 @@ sub run_command {
             sub {
                 $_[1]->Skip(1);
                 $_[1]->GetProcess->Destroy;
-                
+
                 TRACE(' PROCESS_STREAM_EXIT') if DEBUG;
-                
+
                 my $outpanel = $_[0];
                 $outpanel->style_neutral;
-                $outpanel->AppendText( "\nProcess terminated\n");
+                $outpanel->AppendText("\nProcess terminated\n");
                 $panel->set_as_stopped;
-                
-                $doc->process( undef );
+
+                $doc->process(undef);
             },
         );
         $panel->{bound} = 1;
@@ -432,26 +441,26 @@ sub run_command {
     # Check if we started the process or not
     if ( $doc->process ) {
         $panel->set_as_started;
-        
-    } else {
+
+    }
+    else {
 
         # Failed to start the command. Clean up.
-        $panel->set_as_stopped; # should already be stopped, but just in case
+        $panel->set_as_stopped;    # should already be stopped, but just in case
         Wx::MessageBox( sprintf( _T("Failed to start server via '%s'"), $command ), _T("Error"), Wx::wxOK, $self );
     }
 
     return;
 }
 
-# This method belonds in Padre::Plugin::Plack::Panel but we keep it here
-# to speed up the dev edit-reload cycle
+
 sub build_panel {
-    my $self = shift;
+    my $self  = shift;
     my $doc   = shift;
     my $panel = shift;
-    
+
     require Scalar::Util;
-    $panel->{doc}  = $doc;
+    $panel->{doc} = $doc;
     Scalar::Util::weaken( $panel->{doc} );
 
     # main container
@@ -463,49 +472,51 @@ sub build_panel {
     # LED showing process status
     $panel->{led} = Wx::StaticBitmap->new( $panel, -1, Wx::wxNullBitmap );
     $top_box->Add( $panel->{led}, 0, Wx::wxALIGN_CENTER_VERTICAL );
-    
+
     # Servers
     my @servers = sort qw(
-        Standalone
-        Apache1
-        Apache2
-        Apache2::RegistryAnyEvent
-        AnyEvent::HTTPD
-        AnyEvent::ReverseHTTP
-        AnyEvent::SCGI
-        AnyEvent::Server::Starter
-        CGI 
-        Corona
-        FCGI
-        FCGI::Engine
-        HTTP::Server::PSGI
-        HTTP::Server::Simple
-        Server::Simple
-        SCGI
-        Starman
-        Starlet
-        Twiggy
-        POE
-        ReverseHTTP
+      Standalone
+      Apache1
+      Apache2
+      Apache2::RegistryAnyEvent
+      AnyEvent::HTTPD
+      AnyEvent::ReverseHTTP
+      AnyEvent::SCGI
+      AnyEvent::Server::Starter
+      CGI
+      Corona
+      FCGI
+      FCGI::Engine
+      HTTP::Server::PSGI
+      HTTP::Server::Simple
+      Server::Simple
+      SCGI
+      Starman
+      Starlet
+      Twiggy
+      POE
+      ReverseHTTP
     );
     unshift @servers, _T('Let plackup guess');
     $top_box->AddSpacer(5);
     $top_box->Add( Wx::StaticText->new( $panel, -1, _T('Server') . ':' ), 0, Wx::wxALIGN_CENTER_VERTICAL );
-    $panel->{server} = Wx::ComboBox->new( $panel, -1, 'Standalone', Wx::wxDefaultPosition, Wx::wxDefaultSize, [ @servers ], Wx::wxCB_DROPDOWN );
+    $panel->{server} =
+      Wx::ComboBox->new( $panel, -1, 'Standalone', Wx::wxDefaultPosition, Wx::wxDefaultSize, [@servers],
+        Wx::wxCB_DROPDOWN );
     $top_box->Add( $panel->{server}, 0, Wx::wxALIGN_CENTER_VERTICAL );
-    
+
     # Port
     $top_box->AddSpacer(5);
     $top_box->Add( Wx::StaticText->new( $panel, -1, _T('Port') . ':' ), 0, Wx::wxALIGN_CENTER_VERTICAL );
     $panel->{port} = Wx::TextCtrl->new( $panel, -1, '5000' );
     $top_box->Add( $panel->{port}, 0, Wx::wxALIGN_CENTER_VERTICAL );
-    
+
     # Plackup Options
     $top_box->AddSpacer(5);
     $top_box->Add( Wx::StaticText->new( $panel, -1, _T('Options') . ':' ), 0, Wx::wxALIGN_CENTER_VERTICAL );
     $panel->{plackup_options} = Wx::TextCtrl->new( $panel, -1, '' );
     $top_box->Add( $panel->{plackup_options}, 0, Wx::wxALIGN_CENTER_VERTICAL );
-    
+
     # Restart
     $top_box->AddSpacer(5);
     $panel->{restart} = Wx::CheckBox->new( $panel, -1, _T('Auto-Restart') );
@@ -516,10 +527,11 @@ sub build_panel {
     $top_box->AddSpacer(5);
     $panel->{start_stop} = Wx::Button->new( $panel, -1, '' );
     Wx::Event::EVT_BUTTON(
-        $panel, $panel->{start_stop},
+        $panel,
+        $panel->{start_stop},
         sub {
             my $panel = shift;
-            
+
             # Trigger plackup/down
             if ( $panel->{start_stop}->GetLabel eq _T('Start') ) {
                 $doc->plugin->plackup($doc);
@@ -530,12 +542,13 @@ sub build_panel {
         },
     );
     $top_box->Add( $panel->{start_stop}, 0, Wx::wxALIGN_CENTER_VERTICAL );
-    
+
     # Browser
     $top_box->AddSpacer(5);
     $panel->{browse} = Wx::Button->new( $panel, -1, _T('View in Browser') );
     Wx::Event::EVT_BUTTON(
-        $panel, $panel->{browse},
+        $panel,
+        $panel->{browse},
         sub {
             my $panel = shift;
             my $port = $panel->{port}->GetValue || 5000;
@@ -549,19 +562,20 @@ sub build_panel {
 
     # output panel for server
     require Padre::Wx::Output;
-    my $output = Padre::Wx::Output->new($self->main, $panel);
-    
+    my $output = Padre::Wx::Output->new( $self->main, $panel );
+
     $box->Add( $output, 1, Wx::wxGROW );
 
     # wrapping it up
     $panel->SetSizer($box);
 
     # holding on to some objects we'll need to manipulate later on
-    $panel->{output}   = $output;
+    $panel->{output} = $output;
 
     $panel->set_as_stopped;
 }
 
+
 1;
 
 
@@ -573,67 +587,124 @@ Padre::Plugin::Plack - PSGI/Plack plugin for Padre
 
 =head1 VERSION
 
-version 0.101150
+version 1.200
 
 =head1 SYNOPSIS
 
     # cpan install Padre::Plugin::Plack;
-    # Then enable it via L<Padre>, The Perl IDE: 
+    # Then enable it via L<Padre>, The Perl IDE:
     # Padre > Plugins > Plugin Manager > Plack > enable
 
 =head1 DESCRIPTION
 
-As the name suggests, Padre::Plugin::Plack adds L<Plack> awareness to L<Padre>. 
+As the name suggests, Padre::Plugin::Plack adds L<Plack> awareness to L<Padre>.
 
-With the plugin installed, opening *.psgi files causes some special things to 
-happen. 
+With the plugin installed, opening *.psgi files causes some special things to
+happen.
 
-PSGI files are really just ordinary Perl files, so Padre does its normal Perl 
-lexing/syntax highlighting magic on them, but the real fun starts with the 
-Plack-specific features that appear in the per-file graphical L<plackup> control 
-panel that shows up. 
+PSGI files are really just ordinary Perl files, so Padre does its normal Perl
+lexing/syntax highlighting magic on them, but the real fun starts with the
+Plack-specific features that appear in the per-file graphical L<plackup> control
+panel that shows up.
 
-The panel lets you run your web app in a Plack server at the click of a button, 
-view server output, configure plackup options and launch a web browser on the 
+The panel lets you run your web app in a Plack server at the click of a button,
+view server output, configure plackup options and launch a web browser on the
 appropriate port.
 
-The great thing about Plack/PSGI is that unlike my previous plugin 
-(L<Padre::Plugin::WebGUI>) which was specific to a single web app (albeit a big one), 
-this plugin can be used for any web app built in a web framework that supports 
-Plack (L<Catalyst>, L<CGI::Application>, L<HTTP::Engine>, etc..). This is the same 
+The great thing about Plack/PSGI is that unlike my previous plugin
+(L<Padre::Plugin::WebGUI>) which was specific to a single web app (albeit a big one),
+this plugin can be used for any web app built in a web framework that supports
+Plack (L<Catalyst>, L<CGI::Application>, L<HTTP::Engine>, etc..). This is the same
 motivating factor that excites L<Plack::Middleware> authors.
 
-The plugin turns on plackup’s C<--reload> option by default, which conveniently 
-causes the plack server to reload every time you modify your source files in Padre. 
-This makes for quite a nice, if somewhat minimal "Plack IDE" experience 
+The plugin turns on plackup’s C<--reload> option by default, which conveniently
+causes the plack server to reload every time you modify your source files in Padre.
+This makes for quite a nice, if somewhat minimal "Plack IDE" experience
 (this is version 0.01 after all).
 
-The plugin integrates all of the L<Plack> example "dot-psgi”"files as templates 
+The plugin integrates all of the L<Plack> example "dot-psgi”"files as templates
 that can be used to create different types of Plack apps straight from the GUI menu.
 
-The pre-populated list of Plack servers and the simple start/stop button makes for 
-a nice way of exploring the Plack server ecosystem. You can use the other panel 
+The pre-populated list of Plack servers and the simple start/stop button makes for
+a nice way of exploring the Plack server ecosystem. You can use the other panel
 options to enter a specific port to run on, toggle auto-start mode and pass additional
-options to plackup (options that start with C<--> are passed through to the backend 
+options to plackup (options that start with C<--> are passed through to the backend
 server).
 
-The output panel is similar to the output panel that Padre normally displays when you 
-execute Perl files, except that you get one panel per .psgi file meaning that you can 
-run multiple plack servers simultaneously and independently view their output. 
-The appropriate panel is automatically selected when you click on the corresponding 
+The output panel is similar to the output panel that Padre normally displays when you
+execute Perl files, except that you get one panel per .psgi file meaning that you can
+run multiple plack servers simultaneously and independently view their output.
+The appropriate panel is automatically selected when you click on the corresponding
 file tab, and running processes are stopped when you close the tab.
 
-It should be really easy to turn Padre::Plugin::Plack into new plugins that involve the 
-same basic ingredients, namely a file extension and an external command for running those 
-files, with a per-file panel for command options and output. So I encourage anyone who has 
-a similar plugin in mind to steal liberally from Padre::Plugin::Plack (as I did from 
-L<Padre::Plugin::Catalyst> - thanks garu++). 
+It should be really easy to turn Padre::Plugin::Plack into new plugins that involve the
+same basic ingredients, namely a file extension and an external command for running those
+files, with a per-file panel for command options and output. So I encourage anyone who has
+a similar plugin in mind to steal liberally from Padre::Plugin::Plack (as I did from
+L<Padre::Plugin::Catalyst> - thanks garu++).
 Ruby Rack support comes to mind as a trivial example.
 
 Make Padre your domain-specific IDE today :)
 
 Blog post with screenshots: L<http://blog.patspam.com/2009/padrepluginplack>
 
+=head1 METHODS
+
+=head2 padre_interfaces
+
+Declare the Padre interfaces this plugin uses
+
+=head2 registered_documents
+
+Declare ourselves as the handler for .psgi files
+
+=head2 menu_plugins
+
+Create the plugin menu
+
+=head2 on_app_load
+
+Called when Padre loads
+
+=head2 is_psgi_doc
+
+=head2 editor_enable
+
+=head2 editor_changed
+
+=head2 on_panel_load
+
+=head2 on_panel_close
+
+=head2 on_doc_load
+
+Note that the new tab may or may not exist at this point
+When triggered by user opening a new file (e.g. from L<on_app_load>), tab does not exist yet
+Whereas, when triggered by user creating new app from template, tab exists
+
+=head2 on_doc_close
+
+=head2 on_about_load
+
+=head2 load_dot_psgi_examples
+
+=head2 plugin_enable
+
+=head2 plugin_enable
+
+=head2 plackup
+
+=head2 plackdown
+
+=head2 run_command
+
+=head2 build_panel
+
+This method belonds in Padre::Plugin::Plack::Panel but we keep it here
+to speed up the dev edit-reload cycle
+
+=head2 TRACE
+
 =head1 CONTRIBUTORS
 
 =encoding utf8
@@ -648,19 +719,33 @@ Gábor Szabó - גאבור סבו (SZABGAB) E<lt>szabgab@gmail.comE<gt>
 
 =head1 TRANSLATORS
 
+Big thanks to all the wonderful translators!
+
 =over 4
 
 =item *
 
-French - Jerome Quelin (jquelin)
+French - Jerome Quelin (jquelin) E<lt>jquelin@cpan.orgE<gt>
 
 =item *
 
-Dutch - Dirk De Nijs (ddn123456)
+Dutch - Dirk De Nijs (ddn123456) E<lt>DIRKDN@cpan.orgE<gt>
 
 =item *
 
-Brazilian Portuguese - Breno G. de Oliveira (garu)
+Brazilian Portuguese - Breno G. de Oliveira (GARU) E<lt>garu@cpan.orgE<gt>
+
+=item *
+
+Arabic - أحمد محمد زواوي Ahmad M. Zawawi (azawawi) E<lt>ahmad.zawawi@gmail.comE<gt>
+
+=item *
+
+Turkish - Burak Gürsoy (burak) E<lt>burak@cpan.orgE<gt>
+
+=item *
+
+Italian - Simone Blandino (sblandin)
 
 =back
 
@@ -670,7 +755,7 @@ L<Plack>, L<Padre>
 
 =head1 AUTHOR
 
-  Patrick Donelan <pat@patspam.com>
+Patrick Donelan <pdonelan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
